@@ -1092,11 +1092,29 @@ Examples:
 
 Converts the address of the $object to a value of the int type, and returns it.
 
-=head2 get_version_string
+=head2 get_spvm_version_string
 
-  static method get_version_string : string ($class_name : string);
+  static method get_spvm_version_string : string ();
 
-Returns the version string of the class $class_name.
+Returns the the L<version string|SPVM::Document::Language/"Version String"> of the SPVM language.
+
+=head2 get_spvm_version_string
+
+  static method get_spvm_version_string : string ();
+
+Returns the the L<version string|SPVM::Document::Language/"Version String"> of the SPVM language.
+
+=head2 get_spvm_version_number
+
+  static method get_spvm_version_number : double ();
+
+Returns the L<version number|SPVM::Document::Language/"Version Number"> of the SPVM language.
+
+=head2 get_version_number
+
+  static method get_version_number : double ($class_name : string);
+
+Returns the L<version number|SPVM::Document::Language/"Version Number"> of a class.
 
 Exceptions:
 
@@ -1104,22 +1122,6 @@ The $class_name must be defined. Otherwise an exception is thrown.
 
 The class specified by the $class_name must be loaded. Otherwise an exception is thrown.
 
-=head2 get_version_number
-
-  static method get_version_number : double ($class_name : string);
-
-Calls the L</"get_version_string"> method, and the return value is converted to a floating point number using the L</"to_double"> method, and returns it.
-
-Exceptions:
-
-Exceptions of the L</"get_version_string"> method can be thrown.
-
-=head2 get_spvm_version
-
-  static method get_spvm_version : string ();
-
-Returns the version of the SPVM language.
-
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
